==> haskell-aeson-1.0.2.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.0.2.1
id: aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
key: aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encoding Data.Aeson.Parser Data.Aeson.Text
    Data.Aeson.Types Data.Aeson.TH Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Encode
hidden-modules: Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Internal
                Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
                Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
                Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
                Data.Aeson.Types.Internal
abi: 2855b69b12bca10300145f370df88482
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-1.0.2.1
hs-libraries: HSaeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
depends:
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.0.2.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.0.2.1
id: aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M
key: aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encoding Data.Aeson.Parser Data.Aeson.Text
    Data.Aeson.Types Data.Aeson.TH Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Encode
hidden-modules: Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Internal
                Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
                Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
                Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
                Data.Aeson.Types.Internal
abi: 95200e6e789b37a95d8f3b2c2d48feb0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-1.0.2.1
hs-libraries: HSaeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M
depends:
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
